@@ -12,11 +12,12 @@ except ImportError:
     import ConfigParser as configparser
 
 import click
-from github3 import authorize, login, null
-from github3.exceptions import UnprocessableEntity
 from tabulate import tabulate
 
-from img2txt.img2txt import img2txt
+from .lib.github3.api import authorize, login
+from .lib.github3.null import NullObject
+from .lib.github3.exceptions import UnprocessableEntity
+from .lib.img2txt.img2txt import img2txt
 
 
 class GitHub(object):
